# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiAccountCreateRequest
from ..models import ApiAccountCreateResponse
from ..models import ApiAccountLinkRequest
from ..models import ApiAccountLinkResponse
from ..models import ApiAccountLinkTokenResponse
from ..models import ApiAccountResponse
from ..models import ResponseErrorResponse

from ..operations.account import AccountCreate
from ..operations.account import AccountGet
from ..operations.account import AccountLink
from ..operations.account import AccountLinkTokenGet


@same_doc_as(AccountCreate)
def account_create(
    body: ApiAccountCreateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a new AMS account (AccountCreate)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account

        method: POST

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAccountCreateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiAccountCreateResponse (account Created)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountCreate.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AccountCreate)
async def account_create_async(
    body: ApiAccountCreateRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a new AMS account (AccountCreate)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account

        method: POST

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAccountCreateRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiAccountCreateResponse (account Created)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountCreate.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AccountGet)
def account_get(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get the account associated with the namespace. (AccountGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account

        method: GET

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAccountResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountGet.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AccountGet)
async def account_get_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get the account associated with the namespace. (AccountGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account

        method: GET

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAccountResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountGet.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AccountLink)
def account_link(
    body: ApiAccountLinkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Link an account to the namespace.  Will attempt to register the linkage in AMS shipyard.  Requires a valid link token for the account. Fails if an account is already linked (AccountLink)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account/link

        method: POST

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAccountLinkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiAccountLinkResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountLink.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AccountLink)
async def account_link_async(
    body: ApiAccountLinkRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Link an account to the namespace.  Will attempt to register the linkage in AMS shipyard.  Requires a valid link token for the account. Fails if an account is already linked (AccountLink)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [CREATE]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account/link

        method: POST

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiAccountLinkRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiAccountLinkResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountLink.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AccountLinkTokenGet)
def account_link_token_get(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get a linking token for another namespace to use to link to the account to which this namespace is linked.  Fails if no account linked. (AccountLinkTokenGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account/link

        method: GET

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAccountLinkTokenResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountLinkTokenGet.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AccountLinkTokenGet)
async def account_link_token_get_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get a linking token for another namespace to use to link to the account to which this namespace is linked.  Fails if no account linked. (AccountLinkTokenGet)

    Required Permission: ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:ARMADA:ACCOUNT [READ]

    Properties:
        url: /ams/v1/admin/namespaces/{namespace}/account/link

        method: GET

        tags: ["Account"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - ApiAccountLinkTokenResponse (success)

        401: Unauthorized - ResponseErrorResponse (no authorization provided)

        403: Forbidden - ResponseErrorResponse (insufficient permissions)

        404: Not Found - ResponseErrorResponse (account not linked)

        500: Internal Server Error - ResponseErrorResponse (internal server error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AccountLinkTokenGet.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ErrorEntity

from ..operations.anonymization import AnonymizeUserAgreement


@same_doc_as(AnonymizeUserAgreement)
def anonymize_user_agreement(
    user_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Anonymize user's agreement record (anonymizeUserAgreement)

    This API will anonymize agreement record for specified user. Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:*:LEGAL", action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:*:LEGAL [DELETE]

    Properties:
        url: /agreement/admin/users/{userId}/anonymization/agreements

        method: DELETE

        tags: ["Anonymization"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (successful anonymize)

        404: Not Found - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_agreement_not_found)
    """
    request = AnonymizeUserAgreement.create(
        user_id=user_id,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AnonymizeUserAgreement)
async def anonymize_user_agreement_async(
    user_id: str, x_additional_headers: Optional[Dict[str, str]] = None, **kwargs
):
    """Anonymize user's agreement record (anonymizeUserAgreement)

    This API will anonymize agreement record for specified user. Other detail info:

      * Required permission : resource="ADMIN:NAMESPACE:*:LEGAL", action=8 (DELETE)

    Required Permission(s):
        - ADMIN:NAMESPACE:*:LEGAL [DELETE]

    Properties:
        url: /agreement/admin/users/{userId}/anonymization/agreements

        method: DELETE

        tags: ["Anonymization"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH] or [BEARER_AUTH]

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (successful anonymize)

        404: Not Found - ErrorEntity (40045: errors.net.accelbyte.platform.legal.user_agreement_not_found)
    """
    request = AnonymizeUserAgreement.create(
        user_id=user_id,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Ugc Service (2.11.1)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.ugc.models import ModelsAddDownloadCountResponse
from ..api.ugc.models import ModelsAdminGetContentBulkRequest
from ..api.ugc.models import ModelsAdminUpdateContentRequest
from ..api.ugc.models import ModelsChannelRequest
from ..api.ugc.models import ModelsChannelResponse
from ..api.ugc.models import ModelsContentDownloadResponse
from ..api.ugc.models import ModelsContentLikeRequest
from ..api.ugc.models import ModelsContentLikeResponse
from ..api.ugc.models import ModelsCreateContentRequest
from ..api.ugc.models import ModelsCreateContentRequestS3
from ..api.ugc.models import ModelsCreateContentResponse
from ..api.ugc.models import ModelsCreateGroupRequest
from ..api.ugc.models import ModelsCreateGroupResponse
from ..api.ugc.models import ModelsCreateScreenshotRequest
from ..api.ugc.models import ModelsCreateScreenshotRequestItem
from ..api.ugc.models import ModelsCreateScreenshotResponse
from ..api.ugc.models import ModelsCreateTagRequest
from ..api.ugc.models import ModelsCreateTagResponse
from ..api.ugc.models import ModelsCreateTypeRequest
from ..api.ugc.models import ModelsCreateTypeResponse
from ..api.ugc.models import ModelsCreatorFollowState
from ..api.ugc.models import ModelsCreatorOverviewResponse
from ..api.ugc.models import ModelsCreatorResponse
from ..api.ugc.models import ModelsGetContentPreviewResponse
from ..api.ugc.models import ModelsHideContentRequest
from ..api.ugc.models import ModelsLikeState
from ..api.ugc.models import ModelsPaginatedContentDownloadResponse
from ..api.ugc.models import ModelsPaginatedCreatorOverviewResponse
from ..api.ugc.models import ModelsPaginatedGetChannelResponse
from ..api.ugc.models import ModelsPaginatedGetTagResponse
from ..api.ugc.models import ModelsPaginatedGetTypeResponse
from ..api.ugc.models import ModelsPaginatedGroupResponse
from ..api.ugc.models import ModelsPagingCursor
from ..api.ugc.models import ModelsPayloadURL
from ..api.ugc.models import ModelsPreviewMetadata
from ..api.ugc.models import ModelsPreviewURL
from ..api.ugc.models import ModelsPublicChannelRequest
from ..api.ugc.models import ModelsPublicCreateContentRequestS3
from ..api.ugc.models import ModelsPublicGetContentBulkRequest
from ..api.ugc.models import ModelsScreenshotResponse
from ..api.ugc.models import ModelsUpdateChannelRequest
from ..api.ugc.models import ModelsUpdateContentRequest
from ..api.ugc.models import ModelsUpdateScreenshot
from ..api.ugc.models import ModelsUpdateScreenshotRequest
from ..api.ugc.models import ModelsUpdateScreenshotResponse
from ..api.ugc.models import ModelsUserFollowRequest
from ..api.ugc.models import ModelsUserFollowResponse
from ..api.ugc.models import ResponseError


def create_models_add_download_count_response_example() -> (
    ModelsAddDownloadCountResponse
):
    instance = ModelsAddDownloadCountResponse()
    instance.content_id = randomize()
    return instance


def create_models_admin_get_content_bulk_request_example() -> (
    ModelsAdminGetContentBulkRequest
):
    instance = ModelsAdminGetContentBulkRequest()
    instance.content_ids = [randomize()]
    return instance


def create_models_admin_update_content_request_example() -> (
    ModelsAdminUpdateContentRequest
):
    instance = ModelsAdminUpdateContentRequest()
    instance.content_type = randomize()
    instance.file_extension = randomize()
    instance.name = randomize()
    instance.payload = randomize()
    instance.preview = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.update_content_file = randomize("bool")
    instance.custom_attributes = {randomize(): randomize()}
    instance.preview_metadata = create_models_preview_metadata_example()
    instance.share_code = randomize()
    return instance


def create_models_channel_request_example() -> ModelsChannelRequest:
    instance = ModelsChannelRequest()
    instance.name = randomize()
    instance.id_ = randomize()
    return instance


def create_models_channel_response_example() -> ModelsChannelResponse:
    instance = ModelsChannelResponse()
    instance.id_ = randomize()
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.user_id = randomize("uid")
    instance.parent_namespace = randomize("slug")
    return instance


def create_models_content_download_response_example() -> ModelsContentDownloadResponse:
    instance = ModelsContentDownloadResponse()
    instance.channel_id = randomize()
    instance.created_time = randomize()
    instance.creator_follow_state = create_models_creator_follow_state_example()
    instance.creator_name = randomize()
    instance.download_count = randomize("int", min_val=1, max_val=1000)
    instance.file_extension = randomize()
    instance.id_ = randomize()
    instance.is_hidden = randomize("bool")
    instance.is_official = randomize("bool")
    instance.like_count = randomize("int", min_val=1, max_val=1000)
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.share_code = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.updated_time = randomize()
    instance.user_id = randomize("uid")
    instance.custom_attributes = {randomize(): randomize()}
    instance.groups = [randomize()]
    instance.like_state = create_models_like_state_example()
    instance.payload = randomize()
    instance.payload_url = randomize("url")
    instance.preview_url = randomize("url")
    instance.screenshots = [create_models_screenshot_response_example()]
    return instance


def create_models_content_like_request_example() -> ModelsContentLikeRequest:
    instance = ModelsContentLikeRequest()
    instance.like_status = randomize("bool")
    return instance


def create_models_content_like_response_example() -> ModelsContentLikeResponse:
    instance = ModelsContentLikeResponse()
    instance.content_id = randomize()
    instance.like_status = randomize("bool")
    return instance


def create_models_create_content_request_example() -> ModelsCreateContentRequest:
    instance = ModelsCreateContentRequest()
    instance.name = randomize()
    instance.payload = randomize()
    instance.preview = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.custom_attributes = {randomize(): randomize()}
    instance.preview_metadata = create_models_preview_metadata_example()
    return instance


def create_models_create_content_request_s3_example() -> ModelsCreateContentRequestS3:
    instance = ModelsCreateContentRequestS3()
    instance.name = randomize()
    instance.preview = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.content_type = randomize()
    instance.custom_attributes = {randomize(): randomize()}
    instance.file_extension = randomize()
    instance.preview_metadata = create_models_preview_metadata_example()
    instance.share_code = randomize()
    return instance


def create_models_create_content_response_example() -> ModelsCreateContentResponse:
    instance = ModelsCreateContentResponse()
    instance.channel_id = randomize()
    instance.created_time = randomize()
    instance.creator_name = randomize()
    instance.file_extension = randomize()
    instance.id_ = randomize()
    instance.is_hidden = randomize("bool")
    instance.is_official = randomize("bool")
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.parent_namespace = randomize("slug")
    instance.preview = randomize()
    instance.share_code = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.updated_time = randomize()
    instance.user_id = randomize("uid")
    instance.content_type = randomize()
    instance.custom_attributes = {randomize(): randomize()}
    instance.payload_url = randomize("url")
    instance.preview_url = randomize("url")
    return instance


def create_models_create_group_request_example() -> ModelsCreateGroupRequest:
    instance = ModelsCreateGroupRequest()
    instance.contents = [randomize()]
    instance.name = randomize()
    return instance


def create_models_create_group_response_example() -> ModelsCreateGroupResponse:
    instance = ModelsCreateGroupResponse()
    instance.contents = [randomize()]
    instance.created_at = randomize()
    instance.id_ = randomize()
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.parent_namespace = randomize("slug")
    instance.user_id = randomize("uid")
    return instance


def create_models_create_screenshot_request_example() -> ModelsCreateScreenshotRequest:
    instance = ModelsCreateScreenshotRequest()
    instance.screenshots = [create_models_create_screenshot_request_item_example()]
    return instance


def create_models_create_screenshot_request_item_example() -> (
    ModelsCreateScreenshotRequestItem
):
    instance = ModelsCreateScreenshotRequestItem()
    instance.content_type = randomize()
    instance.description = randomize()
    instance.file_extension = randomize()
    return instance


def create_models_create_screenshot_response_example() -> (
    ModelsCreateScreenshotResponse
):
    instance = ModelsCreateScreenshotResponse()
    instance.screenshots = [create_models_screenshot_response_example()]
    return instance


def create_models_create_tag_request_example() -> ModelsCreateTagRequest:
    instance = ModelsCreateTagRequest()
    instance.tag = randomize()
    return instance


def create_models_create_tag_response_example() -> ModelsCreateTagResponse:
    instance = ModelsCreateTagResponse()
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.tag = randomize()
    return instance


def create_models_create_type_request_example() -> ModelsCreateTypeRequest:
    instance = ModelsCreateTypeRequest()
    instance.subtype = [randomize()]
    instance.type_ = randomize()
    return instance


def create_models_create_type_response_example() -> ModelsCreateTypeResponse:
    instance = ModelsCreateTypeResponse()
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.parent_namespace = randomize("slug")
    instance.subtype = [randomize()]
    instance.type_ = randomize()
    return instance


def create_models_creator_follow_state_example() -> ModelsCreatorFollowState:
    instance = ModelsCreatorFollowState()
    instance.state = randomize("bool")
    instance.user_id = randomize("uid")
    return instance


def create_models_creator_overview_response_example() -> ModelsCreatorOverviewResponse:
    instance = ModelsCreatorOverviewResponse()
    instance.follow_count = randomize("int", min_val=1, max_val=1000)
    instance.following_count = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.parent_namespace = randomize("slug")
    instance.total_liked_content = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_creator_response_example() -> ModelsCreatorResponse:
    instance = ModelsCreatorResponse()
    instance.creator_follow_state = create_models_creator_follow_state_example()
    instance.follow_count = randomize("int", min_val=1, max_val=1000)
    instance.following_count = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.parent_namespace = randomize("slug")
    instance.total_liked_content = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_get_content_preview_response_example() -> (
    ModelsGetContentPreviewResponse
):
    instance = ModelsGetContentPreviewResponse()
    instance.preview = randomize()
    instance.preview_url = randomize("url")
    return instance


def create_models_hide_content_request_example() -> ModelsHideContentRequest:
    instance = ModelsHideContentRequest()
    instance.is_hidden = randomize("bool")
    return instance


def create_models_like_state_example() -> ModelsLikeState:
    instance = ModelsLikeState()
    instance.state = randomize("bool")
    instance.user_id = randomize("uid")
    return instance


def create_models_paginated_content_download_response_example() -> (
    ModelsPaginatedContentDownloadResponse
):
    instance = ModelsPaginatedContentDownloadResponse()
    instance.data = [create_models_content_download_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paginated_creator_overview_response_example() -> (
    ModelsPaginatedCreatorOverviewResponse
):
    instance = ModelsPaginatedCreatorOverviewResponse()
    instance.data = [create_models_creator_overview_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paginated_get_channel_response_example() -> (
    ModelsPaginatedGetChannelResponse
):
    instance = ModelsPaginatedGetChannelResponse()
    instance.data = [create_models_channel_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paginated_get_tag_response_example() -> ModelsPaginatedGetTagResponse:
    instance = ModelsPaginatedGetTagResponse()
    instance.data = [create_models_create_tag_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paginated_get_type_response_example() -> (
    ModelsPaginatedGetTypeResponse
):
    instance = ModelsPaginatedGetTypeResponse()
    instance.data = [create_models_create_type_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paginated_group_response_example() -> ModelsPaginatedGroupResponse:
    instance = ModelsPaginatedGroupResponse()
    instance.data = [create_models_create_group_response_example()]
    instance.paging = create_models_paging_cursor_example()
    return instance


def create_models_paging_cursor_example() -> ModelsPagingCursor:
    instance = ModelsPagingCursor()
    instance.first = randomize()
    instance.last = randomize()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_payload_url_example() -> ModelsPayloadURL:
    instance = ModelsPayloadURL()
    instance.source = randomize()
    instance.url = randomize("url")
    return instance


def create_models_preview_metadata_example() -> ModelsPreviewMetadata:
    instance = ModelsPreviewMetadata()
    instance.preview_content_type = randomize()
    instance.preview_file_extension = randomize()
    return instance


def create_models_preview_url_example() -> ModelsPreviewURL:
    instance = ModelsPreviewURL()
    instance.source = randomize()
    instance.url = randomize("url")
    return instance


def create_models_public_channel_request_example() -> ModelsPublicChannelRequest:
    instance = ModelsPublicChannelRequest()
    instance.name = randomize()
    return instance


def create_models_public_create_content_request_s3_example() -> (
    ModelsPublicCreateContentRequestS3
):
    instance = ModelsPublicCreateContentRequestS3()
    instance.name = randomize()
    instance.preview = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.content_type = randomize()
    instance.custom_attributes = {randomize(): randomize()}
    instance.file_extension = randomize()
    instance.preview_metadata = create_models_preview_metadata_example()
    return instance


def create_models_public_get_content_bulk_request_example() -> (
    ModelsPublicGetContentBulkRequest
):
    instance = ModelsPublicGetContentBulkRequest()
    instance.content_ids = [randomize()]
    return instance


def create_models_screenshot_response_example() -> ModelsScreenshotResponse:
    instance = ModelsScreenshotResponse()
    instance.description = randomize()
    instance.file_extension = randomize()
    instance.screenshot_id = randomize()
    instance.source = randomize()
    instance.url = randomize("url")
    instance.content_type = randomize()
    return instance


def create_models_update_channel_request_example() -> ModelsUpdateChannelRequest:
    instance = ModelsUpdateChannelRequest()
    instance.name = randomize()
    return instance


def create_models_update_content_request_example() -> ModelsUpdateContentRequest:
    instance = ModelsUpdateContentRequest()
    instance.content_type = randomize()
    instance.file_extension = randomize()
    instance.name = randomize()
    instance.payload = randomize()
    instance.preview = randomize()
    instance.sub_type = randomize()
    instance.tags = [randomize()]
    instance.type_ = randomize()
    instance.update_content_file = randomize("bool")
    instance.custom_attributes = {randomize(): randomize()}
    instance.preview_metadata = create_models_preview_metadata_example()
    return instance


def create_models_update_screenshot_example() -> ModelsUpdateScreenshot:
    instance = ModelsUpdateScreenshot()
    instance.description = randomize()
    instance.screenshot_id = randomize()
    return instance


def create_models_update_screenshot_request_example() -> ModelsUpdateScreenshotRequest:
    instance = ModelsUpdateScreenshotRequest()
    instance.screenshots = [create_models_update_screenshot_example()]
    return instance


def create_models_update_screenshot_response_example() -> (
    ModelsUpdateScreenshotResponse
):
    instance = ModelsUpdateScreenshotResponse()
    instance.screenshots = [create_models_update_screenshot_example()]
    return instance


def create_models_user_follow_request_example() -> ModelsUserFollowRequest:
    instance = ModelsUserFollowRequest()
    instance.follow_status = randomize("bool")
    return instance


def create_models_user_follow_response_example() -> ModelsUserFollowResponse:
    instance = ModelsUserFollowResponse()
    instance.follow_status = randomize("bool")
    instance.user_id = randomize("uid")
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Iam Service (6.0.1)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.accountcommon_permission import AccountcommonPermission


class ClientmodelClientCreationResponse(Model):
    """Clientmodel client creation response (clientmodel.ClientCreationResponse)

    Properties:
        client_id: (ClientId) REQUIRED str

        client_name: (ClientName) REQUIRED str

        client_permissions: (ClientPermissions) REQUIRED List[AccountcommonPermission]

        namespace: (Namespace) REQUIRED str

        redirect_uri: (RedirectUri) REQUIRED str

        two_factor_enabled: (TwoFactorEnabled) REQUIRED bool
    """

    # region fields

    client_id: str  # REQUIRED
    client_name: str  # REQUIRED
    client_permissions: List[AccountcommonPermission]  # REQUIRED
    namespace: str  # REQUIRED
    redirect_uri: str  # REQUIRED
    two_factor_enabled: bool  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_client_id(self, value: str) -> ClientmodelClientCreationResponse:
        self.client_id = value
        return self

    def with_client_name(self, value: str) -> ClientmodelClientCreationResponse:
        self.client_name = value
        return self

    def with_client_permissions(
        self, value: List[AccountcommonPermission]
    ) -> ClientmodelClientCreationResponse:
        self.client_permissions = value
        return self

    def with_namespace(self, value: str) -> ClientmodelClientCreationResponse:
        self.namespace = value
        return self

    def with_redirect_uri(self, value: str) -> ClientmodelClientCreationResponse:
        self.redirect_uri = value
        return self

    def with_two_factor_enabled(self, value: bool) -> ClientmodelClientCreationResponse:
        self.two_factor_enabled = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id"):
            result["ClientId"] = str(self.client_id)
        elif include_empty:
            result["ClientId"] = ""
        if hasattr(self, "client_name"):
            result["ClientName"] = str(self.client_name)
        elif include_empty:
            result["ClientName"] = ""
        if hasattr(self, "client_permissions"):
            result["ClientPermissions"] = [
                i0.to_dict(include_empty=include_empty)
                for i0 in self.client_permissions
            ]
        elif include_empty:
            result["ClientPermissions"] = []
        if hasattr(self, "namespace"):
            result["Namespace"] = str(self.namespace)
        elif include_empty:
            result["Namespace"] = ""
        if hasattr(self, "redirect_uri"):
            result["RedirectUri"] = str(self.redirect_uri)
        elif include_empty:
            result["RedirectUri"] = ""
        if hasattr(self, "two_factor_enabled"):
            result["TwoFactorEnabled"] = bool(self.two_factor_enabled)
        elif include_empty:
            result["TwoFactorEnabled"] = False
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_id: str,
        client_name: str,
        client_permissions: List[AccountcommonPermission],
        namespace: str,
        redirect_uri: str,
        two_factor_enabled: bool,
        **kwargs,
    ) -> ClientmodelClientCreationResponse:
        instance = cls()
        instance.client_id = client_id
        instance.client_name = client_name
        instance.client_permissions = client_permissions
        instance.namespace = namespace
        instance.redirect_uri = redirect_uri
        instance.two_factor_enabled = two_factor_enabled
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ClientmodelClientCreationResponse:
        instance = cls()
        if not dict_:
            return instance
        if "ClientId" in dict_ and dict_["ClientId"] is not None:
            instance.client_id = str(dict_["ClientId"])
        elif include_empty:
            instance.client_id = ""
        if "ClientName" in dict_ and dict_["ClientName"] is not None:
            instance.client_name = str(dict_["ClientName"])
        elif include_empty:
            instance.client_name = ""
        if "ClientPermissions" in dict_ and dict_["ClientPermissions"] is not None:
            instance.client_permissions = [
                AccountcommonPermission.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["ClientPermissions"]
            ]
        elif include_empty:
            instance.client_permissions = []
        if "Namespace" in dict_ and dict_["Namespace"] is not None:
            instance.namespace = str(dict_["Namespace"])
        elif include_empty:
            instance.namespace = ""
        if "RedirectUri" in dict_ and dict_["RedirectUri"] is not None:
            instance.redirect_uri = str(dict_["RedirectUri"])
        elif include_empty:
            instance.redirect_uri = ""
        if "TwoFactorEnabled" in dict_ and dict_["TwoFactorEnabled"] is not None:
            instance.two_factor_enabled = bool(dict_["TwoFactorEnabled"])
        elif include_empty:
            instance.two_factor_enabled = False
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ClientmodelClientCreationResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ClientmodelClientCreationResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ClientmodelClientCreationResponse,
        List[ClientmodelClientCreationResponse],
        Dict[Any, ClientmodelClientCreationResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "ClientId": "client_id",
            "ClientName": "client_name",
            "ClientPermissions": "client_permissions",
            "Namespace": "namespace",
            "RedirectUri": "redirect_uri",
            "TwoFactorEnabled": "two_factor_enabled",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "ClientId": True,
            "ClientName": True,
            "ClientPermissions": True,
            "Namespace": True,
            "RedirectUri": True,
            "TwoFactorEnabled": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Session Service (2.15.4)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.apimodels_user_response import ApimodelsUserResponse


class ApimodelsKickResponse(Model):
    """Apimodels kick response (apimodels.KickResponse)

    Properties:
        leader_id: (leaderID) REQUIRED str

        members: (members) REQUIRED List[ApimodelsUserResponse]

        party_id: (partyID) REQUIRED str
    """

    # region fields

    leader_id: str  # REQUIRED
    members: List[ApimodelsUserResponse]  # REQUIRED
    party_id: str  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_leader_id(self, value: str) -> ApimodelsKickResponse:
        self.leader_id = value
        return self

    def with_members(self, value: List[ApimodelsUserResponse]) -> ApimodelsKickResponse:
        self.members = value
        return self

    def with_party_id(self, value: str) -> ApimodelsKickResponse:
        self.party_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "leader_id"):
            result["leaderID"] = str(self.leader_id)
        elif include_empty:
            result["leaderID"] = ""
        if hasattr(self, "members"):
            result["members"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.members
            ]
        elif include_empty:
            result["members"] = []
        if hasattr(self, "party_id"):
            result["partyID"] = str(self.party_id)
        elif include_empty:
            result["partyID"] = ""
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        leader_id: str,
        members: List[ApimodelsUserResponse],
        party_id: str,
        **kwargs,
    ) -> ApimodelsKickResponse:
        instance = cls()
        instance.leader_id = leader_id
        instance.members = members
        instance.party_id = party_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApimodelsKickResponse:
        instance = cls()
        if not dict_:
            return instance
        if "leaderID" in dict_ and dict_["leaderID"] is not None:
            instance.leader_id = str(dict_["leaderID"])
        elif include_empty:
            instance.leader_id = ""
        if "members" in dict_ and dict_["members"] is not None:
            instance.members = [
                ApimodelsUserResponse.create_from_dict(i0, include_empty=include_empty)
                for i0 in dict_["members"]
            ]
        elif include_empty:
            instance.members = []
        if "partyID" in dict_ and dict_["partyID"] is not None:
            instance.party_id = str(dict_["partyID"])
        elif include_empty:
            instance.party_id = ""
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApimodelsKickResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApimodelsKickResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApimodelsKickResponse,
        List[ApimodelsKickResponse],
        Dict[Any, ApimodelsKickResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "leaderID": "leader_id",
            "members": "members",
            "partyID": "party_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "leaderID": True,
            "members": True,
            "partyID": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Platform Service."""

__version__ = "4.30.2"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from .cancel_subscription import CancelSubscription
from .check_user_subscription_6c59a6 import CheckUserSubscriptionSubscribableByItemId
from .delete_user_subscription import DeleteUserSubscription
from .get_user_subscription import GetUserSubscription
from .get_user_subscription_a_b2b8e9 import GetUserSubscriptionActivities
from .get_user_subscription_b_a3096e import GetUserSubscriptionBillingHistories
from .grant_days_to_subscription import GrantDaysToSubscription
from .platform_subscribe_subs_ad4f3b import PlatformSubscribeSubscription
from .process_user_subscripti_d07750 import ProcessUserSubscriptionNotification
from .public_cancel_subscription import PublicCancelSubscription
from .public_change_subscript_350ff2 import PublicChangeSubscriptionBillingAccount
from .public_check_user_subsc_16fdcb import (
    PublicCheckUserSubscriptionSubscribableByItemId,
)
from .public_get_user_subscription import PublicGetUserSubscription
from .public_get_user_subscri_c8d5b3 import PublicGetUserSubscriptionBillingHistories
from .public_query_user_subsc_29ae74 import PublicQueryUserSubscriptions
from .public_query_user_subsc_29ae74 import (
    ChargeStatusEnum as PublicQueryUserSubscriptionsChargeStatusEnum,
    StatusEnum as PublicQueryUserSubscriptionsStatusEnum,
    SubscribedByEnum as PublicQueryUserSubscriptionsSubscribedByEnum,
)
from .public_subscribe_subscription import PublicSubscribeSubscription
from .query_subscriptions import QuerySubscriptions
from .query_subscriptions import (
    ChargeStatusEnum as QuerySubscriptionsChargeStatusEnum,
    StatusEnum as QuerySubscriptionsStatusEnum,
    SubscribedByEnum as QuerySubscriptionsSubscribedByEnum,
)
from .query_user_subscriptions import QueryUserSubscriptions
from .query_user_subscriptions import (
    ChargeStatusEnum as QueryUserSubscriptionsChargeStatusEnum,
    StatusEnum as QueryUserSubscriptionsStatusEnum,
    SubscribedByEnum as QueryUserSubscriptionsSubscribedByEnum,
)
from .recurring_charge_subscription import RecurringChargeSubscription



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

"""Auto-generated package that contains models used by the AccelByte Gaming Services Session Browser Service."""

__version__ = "1.15.1"
__author__ = "AccelByte"
__email__ = "dev@accelbyte.net"

# pylint: disable=line-too-long

from ._session import add_player_to_session
from ._session import add_player_to_session_async
from ._session import admin_delete_session
from ._session import admin_delete_session_async
from ._session import admin_get_session
from ._session import admin_get_session_async
from ._session import admin_query_session
from ._session import admin_query_session_async
from ._session import admin_search_sessions_v2
from ._session import admin_search_sessions_v2_async
from ._session import create_session
from ._session import create_session_async
from ._session import delete_session
from ._session import delete_session_async
from ._session import delete_session_local_ds
from ._session import delete_session_local_ds_async
from ._session import get_active_custom_game_sessions
from ._session import get_active_custom_game_sessions_async
from ._session import get_active_matchmaking_game_sessions
from ._session import get_active_matchmaking_game_sessions_async
from ._session import get_recent_player
from ._session import get_recent_player_async
from ._session import get_session
from ._session import get_session_async
from ._session import get_session_by_user_i_ds
from ._session import get_session_by_user_i_ds_async
from ._session import get_session_history_detailed
from ._session import get_session_history_detailed_async
from ._session import get_total_active_session
from ._session import get_total_active_session_async
from ._session import join_session
from ._session import join_session_async
from ._session import remove_player_from_session
from ._session import remove_player_from_session_async
from ._session import update_session
from ._session import update_session_async
from ._session import update_settings
from ._session import update_settings_async
from ._session import user_query_session
from ._session import user_query_session_async



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# Fleet Command (0.1.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model

from ..models.api_fleet_regional_server_counts import ApiFleetRegionalServerCounts


class ApiFleetListItemResponse(Model):
    """Api fleet list item response (api.FleetListItemResponse)

    Properties:
        active_ds: (activeDs) REQUIRED int

        claimed_ds: (claimedDs) REQUIRED int

        counts: (counts) REQUIRED List[ApiFleetRegionalServerCounts]

        id_: (id) REQUIRED str

        image: (image) REQUIRED str

        name: (name) REQUIRED str

        regions: (regions) REQUIRED List[str]
    """

    # region fields

    active_ds: int  # REQUIRED
    claimed_ds: int  # REQUIRED
    counts: List[ApiFleetRegionalServerCounts]  # REQUIRED
    id_: str  # REQUIRED
    image: str  # REQUIRED
    name: str  # REQUIRED
    regions: List[str]  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_active_ds(self, value: int) -> ApiFleetListItemResponse:
        self.active_ds = value
        return self

    def with_claimed_ds(self, value: int) -> ApiFleetListItemResponse:
        self.claimed_ds = value
        return self

    def with_counts(
        self, value: List[ApiFleetRegionalServerCounts]
    ) -> ApiFleetListItemResponse:
        self.counts = value
        return self

    def with_id(self, value: str) -> ApiFleetListItemResponse:
        self.id_ = value
        return self

    def with_image(self, value: str) -> ApiFleetListItemResponse:
        self.image = value
        return self

    def with_name(self, value: str) -> ApiFleetListItemResponse:
        self.name = value
        return self

    def with_regions(self, value: List[str]) -> ApiFleetListItemResponse:
        self.regions = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "active_ds"):
            result["activeDs"] = int(self.active_ds)
        elif include_empty:
            result["activeDs"] = 0
        if hasattr(self, "claimed_ds"):
            result["claimedDs"] = int(self.claimed_ds)
        elif include_empty:
            result["claimedDs"] = 0
        if hasattr(self, "counts"):
            result["counts"] = [
                i0.to_dict(include_empty=include_empty) for i0 in self.counts
            ]
        elif include_empty:
            result["counts"] = []
        if hasattr(self, "id_"):
            result["id"] = str(self.id_)
        elif include_empty:
            result["id"] = ""
        if hasattr(self, "image"):
            result["image"] = str(self.image)
        elif include_empty:
            result["image"] = ""
        if hasattr(self, "name"):
            result["name"] = str(self.name)
        elif include_empty:
            result["name"] = ""
        if hasattr(self, "regions"):
            result["regions"] = [str(i0) for i0 in self.regions]
        elif include_empty:
            result["regions"] = []
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        active_ds: int,
        claimed_ds: int,
        counts: List[ApiFleetRegionalServerCounts],
        id_: str,
        image: str,
        name: str,
        regions: List[str],
        **kwargs,
    ) -> ApiFleetListItemResponse:
        instance = cls()
        instance.active_ds = active_ds
        instance.claimed_ds = claimed_ds
        instance.counts = counts
        instance.id_ = id_
        instance.image = image
        instance.name = name
        instance.regions = regions
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ApiFleetListItemResponse:
        instance = cls()
        if not dict_:
            return instance
        if "activeDs" in dict_ and dict_["activeDs"] is not None:
            instance.active_ds = int(dict_["activeDs"])
        elif include_empty:
            instance.active_ds = 0
        if "claimedDs" in dict_ and dict_["claimedDs"] is not None:
            instance.claimed_ds = int(dict_["claimedDs"])
        elif include_empty:
            instance.claimed_ds = 0
        if "counts" in dict_ and dict_["counts"] is not None:
            instance.counts = [
                ApiFleetRegionalServerCounts.create_from_dict(
                    i0, include_empty=include_empty
                )
                for i0 in dict_["counts"]
            ]
        elif include_empty:
            instance.counts = []
        if "id" in dict_ and dict_["id"] is not None:
            instance.id_ = str(dict_["id"])
        elif include_empty:
            instance.id_ = ""
        if "image" in dict_ and dict_["image"] is not None:
            instance.image = str(dict_["image"])
        elif include_empty:
            instance.image = ""
        if "name" in dict_ and dict_["name"] is not None:
            instance.name = str(dict_["name"])
        elif include_empty:
            instance.name = ""
        if "regions" in dict_ and dict_["regions"] is not None:
            instance.regions = [str(i0) for i0 in dict_["regions"]]
        elif include_empty:
            instance.regions = []
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ApiFleetListItemResponse]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ApiFleetListItemResponse]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ApiFleetListItemResponse,
        List[ApiFleetListItemResponse],
        Dict[Any, ApiFleetListItemResponse],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "activeDs": "active_ds",
            "claimedDs": "claimed_ds",
            "counts": "counts",
            "id": "id_",
            "image": "image",
            "name": "name",
            "regions": "regions",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "activeDs": True,
            "claimedDs": True,
            "counts": True,
            "id": True,
            "image": True,
            "name": True,
            "regions": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

# AccelByte Gaming Services Iam Service (6.0.1)

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from .....core import Operation
from .....core import HeaderStr
from .....core import HttpResponse

from ...models import ModelTokenThirdPartyLinkStatusResponse
from ...models import RestErrorResponse


class AdminGetThirdPartyPlatformTokenLinkStatusV3(Operation):
    """Admin get the link status of the third party platform token with user id. (AdminGetThirdPartyPlatformTokenLinkStatusV3)

    Admin get the link status of the third party platform token with user id.




    This endpoint is used for checking whether the third party user represented by third party token is
    linked with the corresponding user id.





    Notes:






      * Required permission: ADMIN:NAMESPACE:{namespace}:USER:{userId} [READ]





    ## Supported platforms:






      * steam : The platform_tokenâs value is the authentication code returned by Steam.


      * steamopenid : Steam's user authentication method using OpenID 2.0. The platform_token's value is URL generated by Steam on web authentication


      * facebook : The platform_tokenâs value is the authorization code returned by Facebook OAuth


      * google : The platform_tokenâs value is the authorization code returned by Google OAuth


      * oculus : The platform_tokenâs value is a string composed of Oculus's user ID and the nonce separated by a colon (:).


      * twitch : The platform_tokenâs value is the authorization code returned by Twitch OAuth.


      * discord : The platform_tokenâs value is the authorization code returned by Discord OAuth


      * android : The device_id is the Androidâs device ID


      * ios : The device_id is the iOSâs device ID.


      * apple : The platform_tokenâs value is the authorization code returned by Apple OAuth.(We will use this code to generate APP token)


      * device : Every device that doesânt run Android and iOS is categorized as a device. The device_id is the deviceâs ID.


      * justice : The platform_tokenâs value is the designated userâs access token.


      * epicgames : The platform_tokenâs value is an access-token obtained from Epicgames EOS Account Service.


      * ps4 : The platform_tokenâs value is the authorization code returned by Sony OAuth.


      * ps5 : The platform_tokenâs value is the authorization code returned by Sony OAuth.


      * nintendo : The platform_tokenâs value is the authorization code(id_token) returned by Nintendo OAuth.


      * awscognito : The platform_tokenâs value is the aws cognito access token or id token (JWT).


      * live : The platform_tokenâs value is xbox XSTS token


      * xblweb : The platform_tokenâs value is code returned by xbox after login


      * netflix : The platform_tokenâs value is GAT (Gamer Access Token) returned by Netflix backend


      * snapchat : The platform_tokenâs value is the authorization code returned by Snapchat OAuth.

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:USER:{userId} [READ]

    Properties:
        url: /iam/v3/admin/namespaces/{namespace}/users/{userId}/platforms/{platformId}/linkStatus

        method: POST

        tags: ["Users"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        platform_token: (platformToken) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        platform_id: (platformId) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelTokenThirdPartyLinkStatusResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 10208: platform token expired)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20003: forbidden access)

        404: Not Found - RestErrorResponse (10139: platform account not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)
    """

    # region fields

    _url: str = "/iam/v3/admin/namespaces/{namespace}/users/{userId}/platforms/{platformId}/linkStatus"
    _method: str = "POST"
    _consumes: List[str] = ["application/x-www-form-urlencoded"]
    _produces: List[str] = ["application/json"]
    _securities: List[List[str]] = [["BEARER_AUTH"]]
    _location_query: str = None

    platform_token: str  # REQUIRED in [form_data]
    namespace: str  # REQUIRED in [path]
    platform_id: str  # REQUIRED in [path]
    user_id: str  # REQUIRED in [path]

    # endregion fields

    # region properties

    @property
    def url(self) -> str:
        return self._url

    @property
    def method(self) -> str:
        return self._method

    @property
    def consumes(self) -> List[str]:
        return self._consumes

    @property
    def produces(self) -> List[str]:
        return self._produces

    @property
    def securities(self) -> List[List[str]]:
        return self._securities

    @property
    def location_query(self) -> str:
        return self._location_query

    # endregion properties

    # region get methods

    # endregion get methods

    # region get_x_params methods

    def get_all_params(self) -> dict:
        return {
            "form_data": self.get_form_data_params(),
            "path": self.get_path_params(),
        }

    def get_form_data_params(self) -> dict:
        result = {}
        if hasattr(self, "platform_token"):
            result["platformToken"] = self.platform_token
        return result

    def get_path_params(self) -> dict:
        result = {}
        if hasattr(self, "namespace"):
            result["namespace"] = self.namespace
        if hasattr(self, "platform_id"):
            result["platformId"] = self.platform_id
        if hasattr(self, "user_id"):
            result["userId"] = self.user_id
        return result

    # endregion get_x_params methods

    # region is/has methods

    # endregion is/has methods

    # region with_x methods

    def with_platform_token(
        self, value: str
    ) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        self.platform_token = value
        return self

    def with_namespace(self, value: str) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        self.namespace = value
        return self

    def with_platform_id(
        self, value: str
    ) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        self.platform_id = value
        return self

    def with_user_id(self, value: str) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        self.user_id = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "platform_token") and self.platform_token:
            result["platformToken"] = str(self.platform_token)
        elif include_empty:
            result["platformToken"] = ""
        if hasattr(self, "namespace") and self.namespace:
            result["namespace"] = str(self.namespace)
        elif include_empty:
            result["namespace"] = ""
        if hasattr(self, "platform_id") and self.platform_id:
            result["platformId"] = str(self.platform_id)
        elif include_empty:
            result["platformId"] = ""
        if hasattr(self, "user_id") and self.user_id:
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        return result

    # endregion to methods

    # region response methods

    # noinspection PyMethodMayBeStatic
    def parse_response(
        self, code: int, content_type: str, content: Any
    ) -> Tuple[
        Union[None, ModelTokenThirdPartyLinkStatusResponse],
        Union[None, HttpResponse, RestErrorResponse],
    ]:
        """Parse the given response.

        200: OK - ModelTokenThirdPartyLinkStatusResponse (OK)

        400: Bad Request - RestErrorResponse (20002: validation error | 10208: platform token expired)

        401: Unauthorized - RestErrorResponse (20001: unauthorized access)

        403: Forbidden - RestErrorResponse (20003: forbidden access)

        404: Not Found - RestErrorResponse (10139: platform account not found)

        500: Internal Server Error - RestErrorResponse (20000: internal server error)

        ---: HttpResponse (Undocumented Response)

        ---: HttpResponse (Unexpected Content-Type Error)

        ---: HttpResponse (Unhandled Error)
        """
        pre_processed_response, error = self.pre_process_response(
            code=code, content_type=content_type, content=content
        )
        if error is not None:
            return None, None if error.is_no_content() else error
        code, content_type, content = pre_processed_response

        if code == 200:
            return (
                ModelTokenThirdPartyLinkStatusResponse.create_from_dict(content),
                None,
            )
        if code == 400:
            return None, RestErrorResponse.create_from_dict(content)
        if code == 401:
            return None, RestErrorResponse.create_from_dict(content)
        if code == 403:
            return None, RestErrorResponse.create_from_dict(content)
        if code == 404:
            return None, RestErrorResponse.create_from_dict(content)
        if code == 500:
            return None, RestErrorResponse.create_from_dict(content)

        return self.handle_undocumented_response(
            code=code, content_type=content_type, content=content
        )

    # endregion response methods

    # region static methods

    @classmethod
    def create(
        cls,
        platform_token: str,
        namespace: str,
        platform_id: str,
        user_id: str,
        **kwargs,
    ) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        instance = cls()
        instance.platform_token = platform_token
        instance.namespace = namespace
        instance.platform_id = platform_id
        instance.user_id = user_id
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> AdminGetThirdPartyPlatformTokenLinkStatusV3:
        instance = cls()
        if "platformToken" in dict_ and dict_["platformToken"] is not None:
            instance.platform_token = str(dict_["platformToken"])
        elif include_empty:
            instance.platform_token = ""
        if "namespace" in dict_ and dict_["namespace"] is not None:
            instance.namespace = str(dict_["namespace"])
        elif include_empty:
            instance.namespace = ""
        if "platformId" in dict_ and dict_["platformId"] is not None:
            instance.platform_id = str(dict_["platformId"])
        elif include_empty:
            instance.platform_id = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        return instance

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "platformToken": "platform_token",
            "namespace": "namespace",
            "platformId": "platform_id",
            "userId": "user_id",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "platformToken": True,
            "namespace": True,
            "platformId": True,
            "userId": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ApiMatchTicketRequest
from ..models import ApiMatchTicketResponse
from ..models import ApiMatchTicketStatus
from ..models import ResponseError

from ..operations.match_tickets import CreateMatchTicket
from ..operations.match_tickets import DeleteMatchTicket
from ..operations.match_tickets import MatchTicketDetails


@same_doc_as(CreateMatchTicket)
def create_match_ticket(
    body: ApiMatchTicketRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a matchmaking ticket (CreateMatchTicket)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [CREATE]

    Required Scope: social

    Creates a new request for matchmaking.

    Cross Platform: Allow player to play game with "any" registered plaftforms.
    1. Cross Platform can be enabled through session service or create match ticket.
    a. via ticket: specify several cross_platform on create match ticket attributes.
    This value will override player attributes in session service. e.g. cross_platform:[xbox,psn,steam]
    b. via session service: set player/party cross_platform attributes.
    c. Enable match options ruleset with name cross_platform and type "any".
    {
    "name": "co-op",
    "data": {
    "alliance": {
    "min_number": 1,
    "max_number": 1,
    "player_min_number": 1,
    "player_max_number": 4
    },
    "match_options": {
    "options": [
    {ânameâ: âcross_platformâ, âtypeâ: âanyâ}
    ]
    }
    }
    }
    2. Cross Platform can be disabled with specify only ONE cross_platform. Current matchmaking use this behavior. e.g. cross_platform:[xbox]
    3. Matchmaking will consider Party leader cross_platform preference or Session attribute cross_platform preference.
    4. This behavior only works for Default Matchmaker. Custom matchmaker (custom gRPC matchmaker) need to consider this on its own implementation.

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [CREATE]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets

        method: POST

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiMatchTicketRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiMatchTicketResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found when the specified match pool does not exist)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateMatchTicket.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(CreateMatchTicket)
async def create_match_ticket_async(
    body: ApiMatchTicketRequest,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Create a matchmaking ticket (CreateMatchTicket)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [CREATE]

    Required Scope: social

    Creates a new request for matchmaking.

    Cross Platform: Allow player to play game with "any" registered plaftforms.
    1. Cross Platform can be enabled through session service or create match ticket.
    a. via ticket: specify several cross_platform on create match ticket attributes.
    This value will override player attributes in session service. e.g. cross_platform:[xbox,psn,steam]
    b. via session service: set player/party cross_platform attributes.
    c. Enable match options ruleset with name cross_platform and type "any".
    {
    "name": "co-op",
    "data": {
    "alliance": {
    "min_number": 1,
    "max_number": 1,
    "player_min_number": 1,
    "player_max_number": 4
    },
    "match_options": {
    "options": [
    {ânameâ: âcross_platformâ, âtypeâ: âanyâ}
    ]
    }
    }
    }
    2. Cross Platform can be disabled with specify only ONE cross_platform. Current matchmaking use this behavior. e.g. cross_platform:[xbox]
    3. Matchmaking will consider Party leader cross_platform preference or Session attribute cross_platform preference.
    4. This behavior only works for Default Matchmaker. Custom matchmaker (custom gRPC matchmaker) need to consider this on its own implementation.

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [CREATE]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets

        method: POST

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED ApiMatchTicketRequest in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        201: Created - ApiMatchTicketResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found when the specified match pool does not exist)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = CreateMatchTicket.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteMatchTicket)
def delete_match_ticket(
    ticketid: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a match ticket (DeleteMatchTicket)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [DELETE]

    Required Scope: social

    Deletes an existing matchmaking ticket.

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets/{ticketid}

        method: DELETE

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticketid: (ticketid) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteMatchTicket.create(
        ticketid=ticketid,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteMatchTicket)
async def delete_match_ticket_async(
    ticketid: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete a match ticket (DeleteMatchTicket)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [DELETE]

    Required Scope: social

    Deletes an existing matchmaking ticket.

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [DELETE]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets/{ticketid}

        method: DELETE

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticketid: (ticketid) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteMatchTicket.create(
        ticketid=ticketid,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(MatchTicketDetails)
def match_ticket_details(
    ticketid: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get details for a specific match ticket (MatchTicketDetails)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [READ]

    Required Scope: social

    Get details for a specific match ticket

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [READ]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets/{ticketid}

        method: GET

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticketid: (ticketid) REQUIRED str in path

    Responses:
        200: OK - ApiMatchTicketStatus (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = MatchTicketDetails.create(
        ticketid=ticketid,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(MatchTicketDetails)
async def match_ticket_details_async(
    ticketid: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get details for a specific match ticket (MatchTicketDetails)

    Required Permission: NAMESPACE:{namespace}:MATCHMAKING:TICKET [READ]

    Required Scope: social

    Get details for a specific match ticket

    Required Permission(s):
        - NAMESPACE:{namespace}:MATCHMAKING:TICKET [READ]

    Required Scope(s):
        - social

    Properties:
        url: /match2/v1/namespaces/{namespace}/match-tickets/{ticketid}

        method: GET

        tags: ["Match-Tickets", "public"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        ticketid: (ticketid) REQUIRED str in path

    Responses:
        200: OK - ApiMatchTicketStatus (Created)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = MatchTicketDetails.create(
        ticketid=ticketid,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Event Log Service (2.0.2)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from __future__ import annotations
from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import Model


class ModelsGenericQueryPayload(Model):
    """Models generic query payload (models.GenericQueryPayload)

    Properties:
        client_id: (clientId) REQUIRED str

        event_name: (eventName) REQUIRED str

        payload_query: (payloadQuery) REQUIRED Dict[str, Any]

        session_id: (sessionId) REQUIRED str

        trace_id: (traceId) REQUIRED str

        user_id: (userId) REQUIRED str

        version: (version) REQUIRED int
    """

    # region fields

    client_id: str  # REQUIRED
    event_name: str  # REQUIRED
    payload_query: Dict[str, Any]  # REQUIRED
    session_id: str  # REQUIRED
    trace_id: str  # REQUIRED
    user_id: str  # REQUIRED
    version: int  # REQUIRED

    # endregion fields

    # region with_x methods

    def with_client_id(self, value: str) -> ModelsGenericQueryPayload:
        self.client_id = value
        return self

    def with_event_name(self, value: str) -> ModelsGenericQueryPayload:
        self.event_name = value
        return self

    def with_payload_query(self, value: Dict[str, Any]) -> ModelsGenericQueryPayload:
        self.payload_query = value
        return self

    def with_session_id(self, value: str) -> ModelsGenericQueryPayload:
        self.session_id = value
        return self

    def with_trace_id(self, value: str) -> ModelsGenericQueryPayload:
        self.trace_id = value
        return self

    def with_user_id(self, value: str) -> ModelsGenericQueryPayload:
        self.user_id = value
        return self

    def with_version(self, value: int) -> ModelsGenericQueryPayload:
        self.version = value
        return self

    # endregion with_x methods

    # region to methods

    def to_dict(self, include_empty: bool = False) -> dict:
        result: dict = {}
        if hasattr(self, "client_id"):
            result["clientId"] = str(self.client_id)
        elif include_empty:
            result["clientId"] = ""
        if hasattr(self, "event_name"):
            result["eventName"] = str(self.event_name)
        elif include_empty:
            result["eventName"] = ""
        if hasattr(self, "payload_query"):
            result["payloadQuery"] = {
                str(k0): v0 for k0, v0 in self.payload_query.items()
            }
        elif include_empty:
            result["payloadQuery"] = {}
        if hasattr(self, "session_id"):
            result["sessionId"] = str(self.session_id)
        elif include_empty:
            result["sessionId"] = ""
        if hasattr(self, "trace_id"):
            result["traceId"] = str(self.trace_id)
        elif include_empty:
            result["traceId"] = ""
        if hasattr(self, "user_id"):
            result["userId"] = str(self.user_id)
        elif include_empty:
            result["userId"] = ""
        if hasattr(self, "version"):
            result["version"] = int(self.version)
        elif include_empty:
            result["version"] = 0
        return result

    # endregion to methods

    # region static methods

    @classmethod
    def create(
        cls,
        client_id: str,
        event_name: str,
        payload_query: Dict[str, Any],
        session_id: str,
        trace_id: str,
        user_id: str,
        version: int,
        **kwargs,
    ) -> ModelsGenericQueryPayload:
        instance = cls()
        instance.client_id = client_id
        instance.event_name = event_name
        instance.payload_query = payload_query
        instance.session_id = session_id
        instance.trace_id = trace_id
        instance.user_id = user_id
        instance.version = version
        return instance

    @classmethod
    def create_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> ModelsGenericQueryPayload:
        instance = cls()
        if not dict_:
            return instance
        if "clientId" in dict_ and dict_["clientId"] is not None:
            instance.client_id = str(dict_["clientId"])
        elif include_empty:
            instance.client_id = ""
        if "eventName" in dict_ and dict_["eventName"] is not None:
            instance.event_name = str(dict_["eventName"])
        elif include_empty:
            instance.event_name = ""
        if "payloadQuery" in dict_ and dict_["payloadQuery"] is not None:
            instance.payload_query = {
                str(k0): v0 for k0, v0 in dict_["payloadQuery"].items()
            }
        elif include_empty:
            instance.payload_query = {}
        if "sessionId" in dict_ and dict_["sessionId"] is not None:
            instance.session_id = str(dict_["sessionId"])
        elif include_empty:
            instance.session_id = ""
        if "traceId" in dict_ and dict_["traceId"] is not None:
            instance.trace_id = str(dict_["traceId"])
        elif include_empty:
            instance.trace_id = ""
        if "userId" in dict_ and dict_["userId"] is not None:
            instance.user_id = str(dict_["userId"])
        elif include_empty:
            instance.user_id = ""
        if "version" in dict_ and dict_["version"] is not None:
            instance.version = int(dict_["version"])
        elif include_empty:
            instance.version = 0
        return instance

    @classmethod
    def create_many_from_dict(
        cls, dict_: dict, include_empty: bool = False
    ) -> Dict[str, ModelsGenericQueryPayload]:
        return (
            {k: cls.create_from_dict(v, include_empty=include_empty) for k, v in dict_}
            if dict_
            else {}
        )

    @classmethod
    def create_many_from_list(
        cls, list_: list, include_empty: bool = False
    ) -> List[ModelsGenericQueryPayload]:
        return (
            [cls.create_from_dict(i, include_empty=include_empty) for i in list_]
            if list_
            else []
        )

    @classmethod
    def create_from_any(
        cls, any_: any, include_empty: bool = False, many: bool = False
    ) -> Union[
        ModelsGenericQueryPayload,
        List[ModelsGenericQueryPayload],
        Dict[Any, ModelsGenericQueryPayload],
    ]:
        if many:
            if isinstance(any_, dict):
                return cls.create_many_from_dict(any_, include_empty=include_empty)
            elif isinstance(any_, list):
                return cls.create_many_from_list(any_, include_empty=include_empty)
            else:
                raise ValueError()
        else:
            return cls.create_from_dict(any_, include_empty=include_empty)

    @staticmethod
    def get_field_info() -> Dict[str, str]:
        return {
            "clientId": "client_id",
            "eventName": "event_name",
            "payloadQuery": "payload_query",
            "sessionId": "session_id",
            "traceId": "trace_id",
            "userId": "user_id",
            "version": "version",
        }

    @staticmethod
    def get_required_map() -> Dict[str, bool]:
        return {
            "clientId": True,
            "eventName": True,
            "payloadQuery": True,
            "sessionId": True,
            "traceId": True,
            "userId": True,
            "version": True,
        }

    # endregion static methods



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# AccelByte Gaming Services Achievement Service (2.20.0)

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from .utils import randomize

from ..api.achievement.models import ModelsAchievementOrderUpdateRequest
from ..api.achievement.models import ModelsAchievementRequest
from ..api.achievement.models import ModelsAchievementResponse
from ..api.achievement.models import ModelsAchievementUpdateRequest
from ..api.achievement.models import ModelsAdditionalInfo
from ..api.achievement.models import ModelsContributorResponse
from ..api.achievement.models import ModelsGlobalAchievementResponse
from ..api.achievement.models import ModelsIcon
from ..api.achievement.models import ModelsPaginatedAchievementResponse
from ..api.achievement.models import ModelsPaginatedContributorResponse
from ..api.achievement.models import ModelsPaginatedGlobalAchievementResponse
from ..api.achievement.models import ModelsPaginatedTagResponse
from ..api.achievement.models import ModelsPaginatedUserAchievementResponse
from ..api.achievement.models import ModelsPaginatedUserContributionResponse
from ..api.achievement.models import ModelsPagination
from ..api.achievement.models import ModelsPublicAchievementResponse
from ..api.achievement.models import ModelsPublicAchievementsResponse
from ..api.achievement.models import ModelsTagResponse
from ..api.achievement.models import ModelsUserAchievementResponse
from ..api.achievement.models import ModelsUserContributionResponse
from ..api.achievement.models import ResponseError
from ..api.achievement.models import ServiceImportConfigResponse


def create_models_achievement_order_update_request_example() -> (
    ModelsAchievementOrderUpdateRequest
):
    instance = ModelsAchievementOrderUpdateRequest()
    instance.target_order = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_achievement_request_example() -> ModelsAchievementRequest:
    instance = ModelsAchievementRequest()
    instance.achievement_code = randomize()
    instance.default_language = randomize()
    instance.description = {randomize(): randomize()}
    instance.goal_value = randomize("int", min_val=1, max_val=1000)
    instance.hidden = randomize("bool")
    instance.incremental = randomize("bool")
    instance.locked_icons = [create_models_icon_example()]
    instance.name = {randomize(): randomize()}
    instance.stat_code = randomize()
    instance.tags = [randomize()]
    instance.unlocked_icons = [create_models_icon_example()]
    instance.custom_attributes = {randomize(): randomize()}
    instance.global_ = randomize("bool")
    return instance


def create_models_achievement_response_example() -> ModelsAchievementResponse:
    instance = ModelsAchievementResponse()
    instance.achievement_code = randomize()
    instance.created_at = randomize("date")
    instance.default_language = randomize()
    instance.description = {randomize(): randomize()}
    instance.global_ = randomize("bool")
    instance.hidden = randomize("bool")
    instance.incremental = randomize("bool")
    instance.list_order = randomize("int", min_val=1, max_val=1000)
    instance.locked_icons = [create_models_icon_example()]
    instance.name = {randomize(): randomize()}
    instance.namespace = randomize("slug")
    instance.tags = [randomize()]
    instance.unlocked_icons = [create_models_icon_example()]
    instance.updated_at = randomize("date")
    instance.custom_attributes = {randomize(): randomize()}
    instance.goal_value = randomize("int", min_val=1, max_val=1000)
    instance.stat_code = randomize()
    instance.status = randomize()
    return instance


def create_models_achievement_update_request_example() -> (
    ModelsAchievementUpdateRequest
):
    instance = ModelsAchievementUpdateRequest()
    instance.default_language = randomize()
    instance.description = {randomize(): randomize()}
    instance.goal_value = randomize("int", min_val=1, max_val=1000)
    instance.hidden = randomize("bool")
    instance.incremental = randomize("bool")
    instance.locked_icons = [create_models_icon_example()]
    instance.name = {randomize(): randomize()}
    instance.stat_code = randomize()
    instance.tags = [randomize()]
    instance.unlocked_icons = [create_models_icon_example()]
    instance.custom_attributes = {randomize(): randomize()}
    instance.global_ = randomize("bool")
    return instance


def create_models_additional_info_example() -> ModelsAdditionalInfo:
    instance = ModelsAdditionalInfo()
    instance.number_of_achievements = randomize("int", min_val=1, max_val=1000)
    instance.number_of_hidden_achievements = randomize("int", min_val=1, max_val=1000)
    instance.number_of_visible_achievements = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_contributor_response_example() -> ModelsContributorResponse:
    instance = ModelsContributorResponse()
    instance.achievement_code = randomize()
    instance.contributed_value = randomize("int", min_val=1, max_val=1000)
    instance.created_at = randomize("date")
    instance.id_ = randomize()
    instance.namespace = randomize("slug")
    instance.user_id = randomize("uid")
    instance.updated_at = randomize("date")
    return instance


def create_models_global_achievement_response_example() -> (
    ModelsGlobalAchievementResponse
):
    instance = ModelsGlobalAchievementResponse()
    instance.achievement_code = randomize()
    instance.created_at = randomize("date")
    instance.id_ = randomize()
    instance.latest_value = randomize("int", min_val=1, max_val=1000)
    instance.name = {randomize(): randomize()}
    instance.namespace = randomize("slug")
    instance.status = randomize("int", min_val=1, max_val=1000)
    instance.achieved_at = randomize("date")
    instance.updated_at = randomize("date")
    return instance


def create_models_icon_example() -> ModelsIcon:
    instance = ModelsIcon()
    instance.slug = randomize()
    instance.url = randomize("url")
    return instance


def create_models_paginated_achievement_response_example() -> (
    ModelsPaginatedAchievementResponse
):
    instance = ModelsPaginatedAchievementResponse()
    instance.data = [create_models_achievement_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_paginated_contributor_response_example() -> (
    ModelsPaginatedContributorResponse
):
    instance = ModelsPaginatedContributorResponse()
    instance.data = [create_models_contributor_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_paginated_global_achievement_response_example() -> (
    ModelsPaginatedGlobalAchievementResponse
):
    instance = ModelsPaginatedGlobalAchievementResponse()
    instance.data = [create_models_global_achievement_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_paginated_tag_response_example() -> ModelsPaginatedTagResponse:
    instance = ModelsPaginatedTagResponse()
    instance.data = [create_models_tag_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_paginated_user_achievement_response_example() -> (
    ModelsPaginatedUserAchievementResponse
):
    instance = ModelsPaginatedUserAchievementResponse()
    instance.count_info = create_models_additional_info_example()
    instance.data = [create_models_user_achievement_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_paginated_user_contribution_response_example() -> (
    ModelsPaginatedUserContributionResponse
):
    instance = ModelsPaginatedUserContributionResponse()
    instance.data = [create_models_user_contribution_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_pagination_example() -> ModelsPagination:
    instance = ModelsPagination()
    instance.next_ = randomize()
    instance.previous = randomize()
    return instance


def create_models_public_achievement_response_example() -> (
    ModelsPublicAchievementResponse
):
    instance = ModelsPublicAchievementResponse()
    instance.achievement_code = randomize()
    instance.created_at = randomize("date")
    instance.description = randomize()
    instance.global_ = randomize("bool")
    instance.hidden = randomize("bool")
    instance.incremental = randomize("bool")
    instance.list_order = randomize("int", min_val=1, max_val=1000)
    instance.locked_icons = [create_models_icon_example()]
    instance.name = randomize()
    instance.namespace = randomize("slug")
    instance.tags = [randomize()]
    instance.unlocked_icons = [create_models_icon_example()]
    instance.updated_at = randomize("date")
    instance.custom_attributes = {randomize(): randomize()}
    instance.goal_value = randomize("int", min_val=1, max_val=1000)
    instance.stat_code = randomize()
    instance.status = randomize()
    return instance


def create_models_public_achievements_response_example() -> (
    ModelsPublicAchievementsResponse
):
    instance = ModelsPublicAchievementsResponse()
    instance.data = [create_models_public_achievement_response_example()]
    instance.paging = create_models_pagination_example()
    return instance


def create_models_tag_response_example() -> ModelsTagResponse:
    instance = ModelsTagResponse()
    instance.created_at = randomize("date")
    instance.name = randomize()
    instance.namespace = randomize("slug")
    return instance


def create_models_user_achievement_response_example() -> ModelsUserAchievementResponse:
    instance = ModelsUserAchievementResponse()
    instance.achieved_at = randomize("date")
    instance.achievement_code = randomize()
    instance.id_ = randomize()
    instance.latest_value = randomize("int", min_val=1, max_val=1000)
    instance.name = {randomize(): randomize()}
    instance.status = randomize("int", min_val=1, max_val=1000)
    return instance


def create_models_user_contribution_response_example() -> (
    ModelsUserContributionResponse
):
    instance = ModelsUserContributionResponse()
    instance.achievement_code = randomize()
    instance.can_claim_reward = randomize("bool")
    instance.contributed_value = randomize("int", min_val=1, max_val=1000)
    instance.id_ = randomize()
    instance.name = {randomize(): randomize()}
    instance.namespace = randomize("slug")
    instance.user_id = randomize("uid")
    return instance


def create_response_error_example() -> ResponseError:
    instance = ResponseError()
    instance.error_code = randomize("int", min_val=1, max_val=1000)
    instance.error_message = randomize()
    return instance


def create_service_import_config_response_example() -> ServiceImportConfigResponse:
    instance = ServiceImportConfigResponse()
    instance.failed_configs = [randomize()]
    instance.ignored_configs = [randomize()]
    instance.new_configs = [randomize()]
    instance.replaced_configs = [randomize()]
    return instance



# Copyright (c) 2021 AccelByte Inc. All Rights Reserved.
# This is licensed software from AccelByte Inc, for limitations
# and restrictions contact your company contract manager.
#
# Code generated. DO NOT EDIT!

# template file: ags_py_codegen

# pylint: disable=duplicate-code
# pylint: disable=line-too-long
# pylint: disable=missing-function-docstring
# pylint: disable=missing-function-docstring
# pylint: disable=missing-module-docstring
# pylint: disable=too-many-arguments
# pylint: disable=too-many-branches
# pylint: disable=too-many-instance-attributes
# pylint: disable=too-many-lines
# pylint: disable=too-many-locals
# pylint: disable=too-many-public-methods
# pylint: disable=too-many-return-statements
# pylint: disable=too-many-statements
# pylint: disable=unused-import

from typing import Any, Dict, List, Optional, Tuple, Union

from ....core import HeaderStr
from ....core import get_namespace as get_services_namespace
from ....core import run_request
from ....core import run_request_async
from ....core import same_doc_as

from ..models import ModelsDataRetrievalResponse
from ..models import ModelsListPersonalDataResponse
from ..models import ModelsUserDataURL
from ..models import ModelsUserPersonalDataResponse
from ..models import ResponseError

from ..operations.data_retrieval import AdminCancelUserPersonalDataRequest
from ..operations.data_retrieval import AdminGeneratePersonalDataURL
from ..operations.data_retrieval import AdminGetListPersonalDataRequest
from ..operations.data_retrieval import AdminGetUserPersonalDataRequests
from ..operations.data_retrieval import AdminRequestDataRetrieval
from ..operations.data_retrieval import DeleteAdminEmailConfiguration
from ..operations.data_retrieval import GetAdminEmailConfiguration
from ..operations.data_retrieval import PublicCancelUserPersonalDataRequest
from ..operations.data_retrieval import PublicGeneratePersonalDataURL
from ..operations.data_retrieval import PublicGetUserPersonalDataRequests
from ..operations.data_retrieval import PublicRequestDataRetrieval
from ..operations.data_retrieval import SaveAdminEmailConfiguration
from ..operations.data_retrieval import UpdateAdminEmailConfiguration


@same_doc_as(AdminCancelUserPersonalDataRequest)
def admin_cancel_user_personal_data_request(
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Cancel user's personal data requests (AdminCancelUserPersonalDataRequest)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [DELETE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [DELETE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests/{requestDate}

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCancelUserPersonalDataRequest.create(
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminCancelUserPersonalDataRequest)
async def admin_cancel_user_personal_data_request_async(
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Cancel user's personal data requests (AdminCancelUserPersonalDataRequest)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [DELETE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [DELETE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests/{requestDate}

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminCancelUserPersonalDataRequest.create(
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGeneratePersonalDataURL)
def admin_generate_personal_data_url(
    password: str,
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Generate personal data download url (AdminGeneratePersonalDataURL)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests/{requestDate}/generate

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUserDataURL (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGeneratePersonalDataURL.create(
        password=password,
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGeneratePersonalDataURL)
async def admin_generate_personal_data_url_async(
    password: str,
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Generate personal data download url (AdminGeneratePersonalDataURL)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests/{requestDate}/generate

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUserDataURL (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGeneratePersonalDataURL.create(
        password=password,
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetListPersonalDataRequest)
def admin_get_list_personal_data_request(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    request_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list personal data requests (AdminGetListPersonalDataRequest)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        request_date: (requestDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsListPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetListPersonalDataRequest.create(
        limit=limit,
        offset=offset,
        request_date=request_date,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetListPersonalDataRequest)
async def admin_get_list_personal_data_request_async(
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    request_date: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get list personal data requests (AdminGetListPersonalDataRequest)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

        request_date: (requestDate) OPTIONAL str in query

    Responses:
        200: OK - ModelsListPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetListPersonalDataRequest.create(
        limit=limit,
        offset=offset,
        request_date=request_date,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminGetUserPersonalDataRequests)
def admin_get_user_personal_data_requests(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user's personal data requests (AdminGetUserPersonalDataRequests)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserPersonalDataRequests.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminGetUserPersonalDataRequests)
async def admin_get_user_personal_data_requests_async(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user's personal data requests (AdminGetUserPersonalDataRequests)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminGetUserPersonalDataRequests.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(AdminRequestDataRetrieval)
def admin_request_data_retrieval(
    user_id: str,
    password: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Submit user personal data retrieval request (AdminRequestDataRetrieval)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [CREATE]` and scope `account`




    If admin request data for themselves, password is need to be set

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [CREATE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) OPTIONAL str in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsDataRetrievalResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminRequestDataRetrieval.create(
        user_id=user_id,
        password=password,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(AdminRequestDataRetrieval)
async def admin_request_data_retrieval_async(
    user_id: str,
    password: Optional[str] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Submit user personal data retrieval request (AdminRequestDataRetrieval)

    Required permission `ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [CREATE]` and scope `account`




    If admin request data for themselves, password is need to be set

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:INFORMATION:USER:{userId} [CREATE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/users/{userId}/requests

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) OPTIONAL str in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsDataRetrievalResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = AdminRequestDataRetrieval.create(
        user_id=user_id,
        password=password,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(DeleteAdminEmailConfiguration)
def delete_admin_email_configuration(
    emails: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete admin emails configurations (DeleteAdminEmailConfiguration)

    Delete a list of admin email addresses to stop receiving personal data request notification.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [DELETE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [DELETE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        emails: (emails) REQUIRED List[str] in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteAdminEmailConfiguration.create(
        emails=emails,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(DeleteAdminEmailConfiguration)
async def delete_admin_email_configuration_async(
    emails: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Delete admin emails configurations (DeleteAdminEmailConfiguration)

    Delete a list of admin email addresses to stop receiving personal data request notification.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [DELETE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [DELETE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        emails: (emails) REQUIRED List[str] in query

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        403: Forbidden - ResponseError (Forbidden)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = DeleteAdminEmailConfiguration.create(
        emails=emails,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(GetAdminEmailConfiguration)
def get_admin_email_configuration(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get admin email addresses configuration (GetAdminEmailConfiguration)

    Get list of admin email address configuration.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAdminEmailConfiguration.create(
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(GetAdminEmailConfiguration)
async def get_admin_email_configuration_async(
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get admin email addresses configuration (GetAdminEmailConfiguration)

    Get list of admin email address configuration.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [READ]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [READ]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

    Responses:
        200: OK - List[str] (OK)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = GetAdminEmailConfiguration.create(
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicCancelUserPersonalDataRequest)
def public_cancel_user_personal_data_request(
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Cancel user's personal data requests (PublicCancelUserPersonalDataRequest)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests/{requestDate}

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCancelUserPersonalDataRequest.create(
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicCancelUserPersonalDataRequest)
async def public_cancel_user_personal_data_request_async(
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Cancel user's personal data requests (PublicCancelUserPersonalDataRequest)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests/{requestDate}

        method: DELETE

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        409: Conflict - ResponseError (Conflict)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicCancelUserPersonalDataRequest.create(
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGeneratePersonalDataURL)
def public_generate_personal_data_url(
    password: str,
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Generate personal data download url (PublicGeneratePersonalDataURL)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests/{requestDate}/generate

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUserDataURL (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGeneratePersonalDataURL.create(
        password=password,
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGeneratePersonalDataURL)
async def public_generate_personal_data_url_async(
    password: str,
    request_date: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Generate personal data download url (PublicGeneratePersonalDataURL)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests/{requestDate}/generate

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        request_date: (requestDate) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        200: OK - ModelsUserDataURL (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        404: Not Found - ResponseError (Not Found)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGeneratePersonalDataURL.create(
        password=password,
        request_date=request_date,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicGetUserPersonalDataRequests)
def public_get_user_personal_data_requests(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user's personal data requests (PublicGetUserPersonalDataRequests)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserPersonalDataRequests.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicGetUserPersonalDataRequests)
async def public_get_user_personal_data_requests_async(
    user_id: str,
    limit: Optional[int] = None,
    offset: Optional[int] = None,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Get user's personal data requests (PublicGetUserPersonalDataRequests)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests

        method: GET

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

        limit: (limit) OPTIONAL int in query

        offset: (offset) OPTIONAL int in query

    Responses:
        200: OK - ModelsUserPersonalDataResponse (OK)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicGetUserPersonalDataRequests.create(
        user_id=user_id,
        limit=limit,
        offset=offset,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(PublicRequestDataRetrieval)
def public_request_data_retrieval(
    password: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Submit personal data retrieval request (PublicRequestDataRetrieval)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsDataRetrievalResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicRequestDataRetrieval.create(
        password=password,
        user_id=user_id,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(PublicRequestDataRetrieval)
async def public_request_data_retrieval_async(
    password: str,
    user_id: str,
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Submit personal data retrieval request (PublicRequestDataRetrieval)

    Requires valid user access token

    Properties:
        url: /gdpr/public/namespaces/{namespace}/users/{userId}/requests

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/x-www-form-urlencoded"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        password: (password) REQUIRED str in form_data

        namespace: (namespace) REQUIRED str in path

        user_id: (userId) REQUIRED str in path

    Responses:
        201: Created - ModelsDataRetrievalResponse (Created)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = PublicRequestDataRetrieval.create(
        password=password,
        user_id=user_id,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(SaveAdminEmailConfiguration)
def save_admin_email_configuration(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Add admin email address configuration (SaveAdminEmailConfiguration)

    Add admin email address for receiving personal data request notification.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [CREATE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [CREATE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SaveAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(SaveAdminEmailConfiguration)
async def save_admin_email_configuration_async(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Add admin email address configuration (SaveAdminEmailConfiguration)

    Add admin email address for receiving personal data request notification.


    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [CREATE]` and scope `account`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [CREATE]

    Required Scope(s):
        - account

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: POST

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = SaveAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )


@same_doc_as(UpdateAdminEmailConfiguration)
def update_admin_email_configuration(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update admin email address configuration (UpdateAdminEmailConfiguration)

    Update admin email address for receiving personal data request notification.

    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [UPDATE]`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [UPDATE]

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: PUT

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return run_request(request, additional_headers=x_additional_headers, **kwargs)


@same_doc_as(UpdateAdminEmailConfiguration)
async def update_admin_email_configuration_async(
    body: List[str],
    namespace: Optional[str] = None,
    x_additional_headers: Optional[Dict[str, str]] = None,
    **kwargs
):
    """Update admin email address configuration (UpdateAdminEmailConfiguration)

    Update admin email address for receiving personal data request notification.

    Required permission `ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [UPDATE]`

    Required Permission(s):
        - ADMIN:NAMESPACE:{namespace}:EMAIL:CONFIGURATION [UPDATE]

    Properties:
        url: /gdpr/admin/namespaces/{namespace}/emails/configurations

        method: PUT

        tags: ["Data Retrieval"]

        consumes: ["application/json"]

        produces: ["application/json"]

        securities: [BEARER_AUTH]

        body: (body) REQUIRED List[str] in body

        namespace: (namespace) REQUIRED str in path

    Responses:
        204: No Content - (No Content)

        400: Bad Request - ResponseError (Bad Request)

        401: Unauthorized - ResponseError (Unauthorized)

        500: Internal Server Error - ResponseError (Internal Server Error)
    """
    if namespace is None:
        namespace, error = get_services_namespace()
        if error:
            return None, error
    request = UpdateAdminEmailConfiguration.create(
        body=body,
        namespace=namespace,
    )
    return await run_request_async(
        request, additional_headers=x_additional_headers, **kwargs
    )
